#!/usr/bin/env python
##------------------------------------------------------------------------------
##
## cat_cos_copies.py
##
## Create the COS file copies needed to catalog certain types of files 
## in the Science Catalog stage instead of AC.  It was found that having the
## copy files around when genreq runs results in the ingest of these files,
## which is completely unnecessary as they are only needed for cat_cos.
##
##
## Input:
##
## History:
## mm/dd/yy PR    Who        What          
## -------- ----- ---------- --------------------------------------------------
## 03/10/09 62166 Sherbert   Do copy in SC instead of AC
## 04/14/09 62166 Sherbert   fix cdm errors
## 08/17/09 63029 Sherbert   remove the from import: improvements, I hope
## 09/10/10 59963 Sherbert   not nec. an error to feed in non-COS
##
##------------------------------------------------------------------------------

import os
import sys
import ac_pkg 
import create_fake_files_for_cos_cat
import opusutil

moduleName = os.path.basename(sys.argv[0])
SKIP_CATALOG = 23

##------------------------------------------------------------------------------
##
## Method:  usage()
##
## Description: 
##          Print usage message for cat_cos_copies(.py)
##
## Returns: nothing
##
##------------------------------------------------------------------------------
def usage():
    usageMsg = """
            cat_cos_copies.py 

            If no command-line arguments are provided, environment variables 
            must be defined for the 4 arguments.  Otherwise, the arguments are 
            expected to be in this order:

            <KW_SERVER> <KW_DB> <OSF_DATASET> <OSF_DATA_ID> <SKIP_CLASSES> <OUTPATH>

            <KW_SERVER>, <KW_DB> are the keyword server and database 
            <OSF_DATA_ID> helps the program determine what to do
            <SKIP_CLASSES> is taken from the resource file and lists the 
                           data_id's for which no cataloging is expected
                           to occur.  cat_cos will skip these, too.
                           This seems silly.
            <OSF_DATASET> is expected to exist in <OUTPATH>.  
            
            This script will create fake COS files for cataloging 
            (create_fake_files_for_cos_cat.py)

    """
#   opusutil.PrintMsg('F', usageMsg, moduleName)
    print usageMsg
    return

##------------------------------------------------------------------------------
##
## Main
##
##    Create copies of some COS files so cataloging will work correctly.
##
##    Have to pass keyword database information because it is consulted to 
##    get the suffix information for the file copies.
##    
## History:
## mm/dd/yy PR    Who        What          
## -------- ----- ---------- --------------------------------------------------
## 08/12/09 63318 Sherbert   catch an exception
##
##------------------------------------------------------------------------------
## Want this script to be runnable from command line or from pipeline
ac_pkg.banner()
envVars = {}

## IF we change asn_product_status.pl to python, will need to add OPUS_SERVER, OPUS_DB
needThese = ["KW_SERVER", "KW_DB", "OSF_DATASET", "OSF_DATA_ID", "SKIP_CLASSES", "OUTPATH"]
if (len(sys.argv)) == 1:
    opusutil.PrintMsg('D', 'Processing env vars', moduleName )
    try:
        envVars = ac_pkg.envSetUp('env', needThese)
    except RuntimeError, errMsg:
        opusutil.PrintMsg('F', str(errMsg), moduleName)
        usage()
        sys.exit(ac_pkg.GO_ABSENT)
else:
    opusutil.PrintMsg('D', 'Processing cmd line vars', moduleName )
    try:
        envVars = ac_pkg.envSetUp('cmdLine', needThese) 
    except AttributeError, errMsg:
        opusutil.PrintMsg('F', str(errMsg), moduleName)
        usage()
        sys.exit(ac_pkg.GO_ABSENT)

KW_SERVER   = envVars["KW_SERVER"] 
KW_DB       = envVars["KW_DB"] 
rootname    = envVars["OSF_DATASET"]
data_id     = envVars["OSF_DATA_ID"]
skip_these  = envVars["SKIP_CLASSES"].strip('"')
caldir      = envVars["OUTPATH"]

## Verify and cd to caldir
try:
    ac_pkg.verify_n_cd_to_dir(caldir)
except RuntimeError, errMsg:
    opusutil.PrintMsg('E', str(errMsg), 'ac_pkg.verify_n_cd_to_dir')
    sys.exit(ac_pkg.GO_ABSENT)

ID   = '-------------- Before COS Catalog '
strt = 'Started for   '
endg = 'Completed for '
ID2  = rootname + ' ' + data_id + ' --------------'
strtMsg = ID + strt + ID2
endgMsg = ID + endg + ID2
opusutil.PrintMsg('I', strtMsg )

## Verify we are dealing with COS science data before calling
## the script to create file copies for catalog
#print "## skip_these is ", skip_these
skip_these = skip_these.split(",")
#print "## skip_these is ", skip_these
if data_id in skip_these:
    msg = "No need to catalog " +data_id+ " data " + rootname
    opusutil.PrintMsg('I', msg, moduleName )
    opusutil.PrintMsg('I', endgMsg )
    sys.exit(SKIP_CATALOG)

if ac_pkg.verify_SI(rootname, "COS"):
    msg = "Calling create_fake_files_for_cos_cat for COS "
    opusutil.PrintMsg('D', msg, moduleName )
    status = create_fake_files_for_cos_cat.doIt(envVars)
    if ac_pkg.ALL_IS_WELL != status :
        msg = "-- " + rootname + " fails"
        opusutil.PrintMsg('E', msg, moduleName )
else: ## It could happen (e.g. command-line catalog tool)
    msg = rootname + ' is NOT a COS dataset.  Exiting. ' 
    opusutil.PrintMsg( 'I', msg, moduleName )
    status = ac_pkg.QUIT_THIS_DATASET

opusutil.PrintMsg('I', endgMsg )
## No need to attempt to capture errors, because failure to close 
## is not an error
opusutil.CloseTrl()

sys.exit(status)
